@@ -17,6 +17,11 @@ import aws_cdk.aws_ssm
 import aws_cdk.core
 import aws_cdk.custom_resources
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-eks", "1.33.0", __name__[0:-6], "aws-eks@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
